@@ -5,6 +5,7 @@ details, see https://github.com/refresh-bio/FAMSA.
 
 import subprocess
 from pathlib import Path
+import tempfile
 
 import numpy as np
 import pandas as pd
@@ -22,7 +23,7 @@ from albion_similog.log import setup_logger
 
 logger = setup_logger(__name__)
 
-FAMSA_PATH = Path("/tmp/famsa-workdir")
+FAMSA_PATH = Path(tempfile.TemporaryDirectory(prefix="famsa-workdir-").name)
 FAMSA_PATH.mkdir(exist_ok=True)
 
 
@@ -487,7 +488,9 @@ class WellCorrelation:
             {
                 self._match_column: np.repeat(consensus[mask_consensus], self._min_seg),
                 self._depth_column: np.linspace(
-                    0, mask_consensus.sum() - 1, mask_consensus.sum() * self._min_seg
+                    0,
+                    (mask_consensus.sum() - 1) * self._min_seg,
+                    mask_consensus.sum() * self._min_seg,
                 )
                 / 10,
                 "freq": np.repeat(
@@ -502,9 +505,7 @@ class WellCorrelation:
             preprocessing.scale(self.consensus[self._match_column])
         )
         seg_signal = binseg_ordered_indices(scaled_data, 2, self._nb_markers)
-        self.consensus_depth = self.consensus.iloc[seg_signal // self._min_seg][
-            self._depth_column
-        ]
+        self.consensus_depth = self.consensus.iloc[seg_signal][self._depth_column]
 
 
 def compute_markers(tops, df_aligned_depths, consensus, depth_column):
